@@ -15,7 +15,6 @@ from threading import Thread
 relay = MediaRelay()
 
 
-
 def synchronize_async_helper(to_await):
     async_response = []
 
@@ -144,6 +143,110 @@ class GSPeerConnectionWatcher:
         await self.sio.wait()
 
 
+class GSPeerConnectionWatcherNew:
+
+    def __init__(self):
+        self.sio = None
+        self.oncommand = None
+
+    async def sendCommand(self, command: GSCOMMAND, value):
+        await self.sio.emit("command", {"type": command, "value": value})
+
+    @classmethod
+    async def create(cls, connectionWatcher, gsdbs, target, onframe=None, onmessage=None, ontrack=None,
+                     ontrackended=None):
+        self = connectionWatcher
+        self.rtconfiList = []
+        self.sio = socketio.AsyncClient()
+        self.gsdbs = gsdbs
+        self.onframe = onframe
+        self.target = target
+        self.onmessage = onmessage
+        self.ontrack = ontrack
+        self.ontrackended = ontrackended
+        self.logger = logging.getLogger(__name__)
+
+        if self.gsdbs.credentials["stunenable"]:
+            self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["stunserver"]))
+        if self.gsdbs.credentials["turnenable"]:
+            self.rtconfiList.append(RTCIceServer(self.gsdbs.credentials["turnserver"],
+                                                 self.gsdbs.credentials["turnuser"],
+                                                 self.gsdbs.credentials["turnpw"]))
+
+        @self.sio.event
+        async def connect():
+            self.logger.info('connection established')
+
+        @self.sio.event
+        async def joined(id):
+            self.logger.info("joined")
+            await self.sio.emit("broadcaster", {"id": id, "target": self.target})
+
+        @self.sio.event
+        async def watcher(id, description):
+            if len(self.rtconfiList) > 0:
+                self.peerConnections = RTCPeerConnection(configuration=RTCConfiguration(self.rtconfiList))
+            else:
+                self.peerConnections = RTCPeerConnection()
+
+            self.peerConnections.addTransceiver('video', direction='recvonly')
+
+            @self.peerConnections.on("iceconnectionstatechange")
+            async def on_iceconnectionstatechange():
+                if self.peerConnections.iceConnectionState == "complete":
+                    pass
+
+                if self.peerConnections.iceConnectionState == "failed":
+                    await self.peerConnections.close()
+
+            @self.peerConnections.on("track")
+            async def on_track(track):
+                if track.kind == "video":
+                    if self.ontrack is not None:
+                        self.logger.info("on track received.Recording started")
+                        await self.ontrack(self.gsdbs, track, self.target)
+                    if self.onframe is not None:
+                        self.logger.info("on track received. onframe started")
+                        gsmediaconsumer = GSMediaConsumer(self.gsdbs, self.target, self.onframe)
+                        gsmediaconsumer.addTrack(track)
+                        await gsmediaconsumer.start()
+
+            await self.peerConnections.setRemoteDescription(description)
+            await self.peerConnections.setLocalDescription(await self.peerConnections.createAnswer())
+
+            await self.sio.emit("answer",
+                                {"target": self.target,
+                                 "sdp": {"type": self.peerConnections.localDescription.type,
+                                         "sdp": self.peerConnections.localDescription.sdp}})
+
+        @self.sio.event
+        async def answer(id, description):
+            if isinstance(description, dict):
+                desc = type('new_dict', (object,), description)
+            else:
+                desc = type('new_dict', (object,), ast.literal_eval(description))
+            await self.peerConnections.setRemoteDescription(desc)
+
+        @self.sio.event
+        async def disconnect(id, target):
+            self.logger.info("Socket connection list")
+            await self.ontrackended(self.gsdbs, target)
+
+        @self.sio.event
+        async def disconnectPeer(id, target):
+            self.logger.info("Camera connection list")
+            await self.ontrackended(self.gsdbs, target)
+
+        if "localhost" in self.gsdbs.credentials["signalserver"]:
+            connectURL = f'{self.gsdbs.credentials["signalserver"]}:{str(self.gsdbs.credentials["signalport"])}'
+        else:
+            connectURL = self.gsdbs.credentials["signalserver"]
+
+        await self.sio.connect(
+            f'{connectURL}?gssession={self.gsdbs.cookiejar.get("session")}.{self.gsdbs.cookiejar.get("signature")}{self.gsdbs.credentials["cnode"]}&target={self.target}')
+        await self.sio.wait()
+
+
 class FrameBufferThread(Thread):
     def __init__(self, gsdbs, target, onframe):
         super(FrameBufferThread, self).__init__()
